@@ -20,6 +20,7 @@ import (
 	"github.com/brimdata/zed/lake/branches"
 	"github.com/brimdata/zed/lake/index"
 	"github.com/brimdata/zed/lakeparse"
+	"github.com/brimdata/zed/runtime/exec"
 	"github.com/brimdata/zed/zio/zngio"
 	"github.com/brimdata/zed/zson"
 	"github.com/segmentio/ksuid"
@@ -94,6 +95,11 @@ type Response struct {
 	Duration time.Duration
 }
 
+// Do sends an HTTP request and returns an HTTP response, refreshing the auth
+// token if necessary.
+//
+// As for net/http.Client.Do, if the returned error is nil, the user is expected
+// to call Response.Body.Close.
 func (c *Connection) Do(req *Request) (*Response, error) {
 	for i := 0; ; i++ {
 		httpreq, err := req.HTTPRequest()
@@ -105,6 +111,7 @@ func (c *Connection) Do(req *Request) (*Response, error) {
 			return nil, err
 		}
 		if res.StatusCode < 200 || res.StatusCode > 299 {
+			// parseError calls res.Body.Close.
 			err = parseError(res)
 			var reserr *ErrorResponse
 			if i == 0 && res.StatusCode == 401 && errors.As(err, &reserr) && reserr.Err.Error() == "invalid token" {
@@ -128,7 +135,8 @@ func (c *Connection) doAndUnmarshal(req *Request, v interface{}, templates ...in
 	if err != nil {
 		return err
 	}
-	zr := zngio.NewReader(res.Body, zed.NewContext())
+	defer res.Body.Close()
+	zr := zngio.NewReader(zed.NewContext(), res.Body)
 	defer zr.Close()
 	rec, err := zr.Read()
 	if err != nil || rec == nil {
@@ -177,10 +185,10 @@ func (c *Connection) NewRequest(ctx context.Context, method, path string, body i
 func (c *Connection) Ping(ctx context.Context) (time.Duration, error) {
 	req := c.NewRequest(ctx, http.MethodGet, "/status", nil)
 	res, err := c.Do(req)
-	res.Body.Close()
 	if err != nil {
 		return 0, err
 	}
+	res.Body.Close()
 	return res.Duration, nil
 }
 
@@ -194,9 +202,9 @@ func (c *Connection) Version(ctx context.Context) (string, error) {
 	return res.Version, nil
 }
 
-func (c *Connection) PoolStats(ctx context.Context, id ksuid.KSUID) (lake.PoolStats, error) {
+func (c *Connection) PoolStats(ctx context.Context, id ksuid.KSUID) (exec.PoolStats, error) {
 	req := c.NewRequest(ctx, http.MethodGet, path.Join("/pool", id.String(), "stats"), nil)
-	var stats lake.PoolStats
+	var stats exec.PoolStats
 	err := c.doAndUnmarshal(req, &stats)
 	if errIsStatus(err, http.StatusNotFound) {
 		err = ErrPoolNotFound
@@ -228,18 +236,24 @@ func (c *Connection) CreatePool(ctx context.Context, payload api.PoolPostRequest
 func (c *Connection) RenamePool(ctx context.Context, id ksuid.KSUID, put api.PoolPutRequest) error {
 	req := c.NewRequest(ctx, http.MethodPut, path.Join("/pool", id.String()), put)
 	res, err := c.Do(req)
+	if err != nil {
+		return err
+	}
 	res.Body.Close()
-	return err
+	return nil
 }
 
 func (c *Connection) RemovePool(ctx context.Context, id ksuid.KSUID) error {
 	req := c.NewRequest(ctx, http.MethodDelete, path.Join("/pool", id.String()), nil)
 	res, err := c.Do(req)
-	res.Body.Close()
-	if errIsStatus(err, http.StatusNotFound) {
-		err = ErrPoolNotFound
+	if err != nil {
+		if errIsStatus(err, http.StatusNotFound) {
+			return ErrPoolNotFound
+		}
+		return err
 	}
-	return err
+	res.Body.Close()
+	return nil
 }
 
 func (c *Connection) CreateBranch(ctx context.Context, poolID ksuid.KSUID, payload api.BranchPostRequest) (branches.Config, error) {
@@ -274,6 +288,10 @@ func (c *Connection) Revert(ctx context.Context, poolID ksuid.KSUID, branchName
 	return commit, err
 }
 
+// Query assembles a query from src and filenames and runs it.
+//
+// As for Connection.Do, if the returned error is nil, the user is expected to
+// call Response.Body.Close.
 func (c *Connection) Query(ctx context.Context, head *lakeparse.Commitish, src string, filenames ...string) (*Response, error) {
 	src, srcInfo, err := parser.ConcatSource(filenames, src)
 	if err != nil {
@@ -296,6 +314,17 @@ func (c *Connection) Query(ctx context.Context, head *lakeparse.Commitish, src s
 	return res, err
 }
 
+func (c *Connection) Compact(ctx context.Context, poolID ksuid.KSUID, branchName string, objects []ksuid.KSUID, message api.CommitMessage) (api.CommitResponse, error) {
+	path := urlPath("pool", poolID.String(), "branch", branchName, "compact")
+	req := c.NewRequest(ctx, http.MethodPost, path, api.CompactRequest{objects})
+	if err := encodeCommitMessage(req, message); err != nil {
+		return api.CommitResponse{}, err
+	}
+	var commit api.CommitResponse
+	err := c.doAndUnmarshal(req, &commit)
+	return commit, err
+}
+
 func (c *Connection) Load(ctx context.Context, poolID ksuid.KSUID, branchName string, r io.Reader, message api.CommitMessage) (api.CommitResponse, error) {
 	path := urlPath("pool", poolID.String(), "branch", branchName)
 	req := c.NewRequest(ctx, http.MethodPost, path, r)
@@ -311,8 +340,11 @@ func (c *Connection) AddIndexRules(ctx context.Context, rules []index.Rule) erro
 	body := api.IndexRulesAddRequest{Rules: rules}
 	req := c.NewRequest(ctx, http.MethodPost, "/index", body)
 	res, err := c.Do(req)
+	if err != nil {
+		return err
+	}
 	res.Body.Close()
-	return err
+	return nil
 }
 
 func (c *Connection) DeleteIndexRules(ctx context.Context, ids []ksuid.KSUID) (api.IndexRulesDeleteResponse, error) {
