@@ -8,6 +8,7 @@ import (
 	"os"
 	"regexp"
 
+	"github.com/brimdata/zed/cli/auto"
 	"github.com/brimdata/zed/pkg/storage"
 	"github.com/brimdata/zed/pkg/terminal"
 	"github.com/brimdata/zed/pkg/terminal/color"
@@ -22,6 +23,7 @@ type Flags struct {
 	anyio.WriterOpts
 	DefaultFormat string
 	split         string
+	splitSize     auto.Bytes
 	outputFile    string
 	forceBinary   bool
 	jsonShortcut  bool
@@ -38,8 +40,10 @@ func (f *Flags) Options() anyio.WriterOpts {
 func (f *Flags) setFlags(fs *flag.FlagSet) {
 	// zio stuff
 	fs.BoolVar(&f.color, "color", true, "enable/disable color formatting for -Z and lake text output")
-	fs.IntVar(&f.ZNG.LZ4BlockSize, "znglz4blocksize", zngio.DefaultLZ4BlockSize,
-		"LZ4 block size in bytes for ZNG compression (nonpositive to disable)")
+	f.ZNG = &zngio.WriterOpts{}
+	fs.BoolVar(&f.ZNG.Compress, "zngcompress", true, "compress ZNG frames")
+	fs.IntVar(&f.ZNG.FrameThresh, "zngframethresh", zngio.DefaultFrameThresh,
+		"minimum ZNG frame size in uncompressed bytes")
 	fs.IntVar(&f.ZSON.Pretty, "pretty", 4,
 		"tab size to pretty print ZSON output (0 for newline-delimited ZSON")
 	fs.StringVar(&f.zsonPersist, "persist", "",
@@ -50,7 +54,10 @@ func (f *Flags) setFlags(fs *flag.FlagSet) {
 	fs.Var(&f.Zst.SkewThresh, "skewtresh", "minimum skew size (MiB) used to group zst columns")
 
 	// emitter stuff
-	fs.StringVar(&f.split, "split", "", "split output into one file per data type with the given path prefix")
+	fs.StringVar(&f.split, "split", "",
+		"split output into one file per data type in this directory (but see -splitsize)")
+	fs.Var(&f.splitSize, "splitsize",
+		"if >0 and -split is set, split into files at least this big rather than by data type")
 	fs.StringVar(&f.outputFile, "o", "", "write data to output file")
 }
 
@@ -100,7 +107,8 @@ func (f *Flags) Init() error {
 	if f.outputFile == "-" {
 		f.outputFile = ""
 	}
-	if f.outputFile == "" && f.Format == "zng" && terminal.IsTerminalFile(os.Stdout) && !f.forceBinary {
+	if f.outputFile == "" && f.split == "" && f.Format == "zng" && !f.forceBinary &&
+		terminal.IsTerminalFile(os.Stdout) {
 		f.Format = "zson"
 		f.ZSON.Pretty = 0
 	}
@@ -117,6 +125,9 @@ func (f *Flags) Open(ctx context.Context, engine storage.Engine) (zio.WriteClose
 		if err != nil {
 			return nil, fmt.Errorf("-split option: %w", err)
 		}
+		if size := f.splitSize.Bytes; size > 0 {
+			return emitter.NewSizeSplitter(ctx, engine, dir, f.outputFile, f.WriterOpts, int64(size))
+		}
 		d, err := emitter.NewSplit(ctx, engine, dir, f.outputFile, f.WriterOpts)
 		if err != nil {
 			return nil, err
