@@ -8,7 +8,8 @@ import (
 
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/cli/outputflags"
-	"github.com/brimdata/zed/cli/procflags"
+	"github.com/brimdata/zed/cli/runtimeflags"
+	"github.com/brimdata/zed/compiler"
 	"github.com/brimdata/zed/lake/api"
 	"github.com/brimdata/zed/lake/index"
 	"github.com/brimdata/zed/pkg/charm"
@@ -20,16 +21,30 @@ import (
 
 var create = &charm.Spec{
 	Name:  "create",
-	Usage: "create [options] rule-name pattern",
+	Usage: "create [options] rule-name rule-type value",
 	Short: "create an index rule for a lake",
-	New:   newCreate,
+	Long: `
+The index create command creates an index rule that can be applied to any
+pool in the Zed lake.  The command takes three arguments: the name of the rule,
+the type of the rule, and the value for the rule.
+
+The name of the index rule must be unique.
+
+The rule's type can be either field, type, or agg (currently only field rules
+are supported).
+
+For field index rules the final argument is the name of the field to index.
+
+Example: zed index create IPs field src.ip
+`,
+	New: newCreate,
 }
 
 type createCommand struct {
 	*Command
-	framesize   int
-	outputFlags outputflags.Flags
-	procFlags   procflags.Flags
+	framesize    int
+	outputFlags  outputflags.Flags
+	runtimeFlags runtimeflags.Flags
 }
 
 func newCreate(parent charm.Command, f *flag.FlagSet) (charm.Command, error) {
@@ -37,12 +52,12 @@ func newCreate(parent charm.Command, f *flag.FlagSet) (charm.Command, error) {
 	f.IntVar(&c.framesize, "framesize", 32*1024, "minimum frame size used in microindex file")
 	c.outputFlags.DefaultFormat = "lake"
 	c.outputFlags.SetFlags(f)
-	c.procFlags.SetFlags(f)
+	c.runtimeFlags.SetFlags(f)
 	return c, nil
 }
 
 func (c *createCommand) Run(args []string) error {
-	ctx, cleanup, err := c.Init(&c.procFlags, &c.outputFlags)
+	ctx, cleanup, err := c.Init(&c.outputFlags, &c.runtimeFlags)
 	if err != nil {
 		return err
 	}
@@ -123,7 +138,7 @@ func parseRule(args []string, ruleName string) ([]string, index.Rule, error) {
 			return nil, nil, errors.New("agg index rule requires a script argument")
 		}
 		script := args[1]
-		rule, err := index.NewAggRule(ruleName, script)
+		rule, err := index.NewAggRule(compiler.NewCompiler(), ruleName, script)
 		return args[2:], rule, err
 	default:
 		return nil, nil, fmt.Errorf("unknown index rule type: %q", args[0])
