@@ -11,10 +11,10 @@ import (
 	"time"
 
 	"github.com/brimdata/zed"
-	"github.com/brimdata/zed/cli"
+	"github.com/brimdata/zed/cli/commitflags"
 	"github.com/brimdata/zed/cli/inputflags"
 	"github.com/brimdata/zed/cli/lakeflags"
-	"github.com/brimdata/zed/cli/procflags"
+	"github.com/brimdata/zed/cli/runtimeflags"
 	"github.com/brimdata/zed/cmd/zed/root"
 	"github.com/brimdata/zed/pkg/charm"
 	"github.com/brimdata/zed/pkg/display"
@@ -38,10 +38,9 @@ The load command adds data to a pool and commits it to a branch.
 
 type Command struct {
 	*root.Command
-	commit bool
-	cli.CommitFlags
-	procFlags  procflags.Flags
-	inputFlags inputflags.Flags
+	commitFlags  commitflags.Flags
+	inputFlags   inputflags.Flags
+	runtimeFlags runtimeflags.Flags
 
 	// status output
 	ctx       context.Context
@@ -51,17 +50,15 @@ type Command struct {
 }
 
 func New(parent charm.Command, f *flag.FlagSet) (charm.Command, error) {
-	c := &Command{
-		Command: parent.(*root.Command),
-	}
-	c.CommitFlags.SetFlags(f)
+	c := &Command{Command: parent.(*root.Command)}
+	c.commitFlags.SetFlags(f)
 	c.inputFlags.SetFlags(f, true)
-	c.procFlags.SetFlags(f)
+	c.runtimeFlags.SetFlags(f)
 	return c, nil
 }
 
 func (c *Command) Run(args []string) error {
-	ctx, cleanup, err := c.Init(&c.inputFlags, &c.procFlags)
+	ctx, cleanup, err := c.Init(&c.inputFlags, &c.runtimeFlags)
 	if err != nil {
 		return err
 	}
@@ -102,7 +99,8 @@ func (c *Command) Run(args []string) error {
 		d = display.New(c, time.Second/2, os.Stderr)
 		go d.Run()
 	}
-	commitID, err := lake.Load(ctx, zctx, poolID, head.Branch, zio.ConcatReader(readers...), c.CommitMessage())
+	message := c.commitFlags.CommitMessage()
+	commitID, err := lake.Load(ctx, zctx, poolID, head.Branch, zio.ConcatReader(readers...), message)
 	if d != nil {
 		d.Close()
 	}
