@@ -8,8 +8,8 @@ type Expr interface {
 
 type (
 	ArrayExpr struct {
-		Kind  string `json:"kind" unpack:""`
-		Exprs []Expr `json:"exprs"`
+		Kind  string       `json:"kind" unpack:""`
+		Elems []VectorElem `json:"elems"`
 	}
 	Assignment struct {
 		Kind string `json:"kind" unpack:""`
@@ -79,8 +79,8 @@ type (
 		Expr  Expr   `json:"expr"`
 	}
 	SetExpr struct {
-		Kind  string `json:"kind" unpack:""`
-		Exprs []Expr `json:"exprs"`
+		Kind  string       `json:"kind" unpack:""`
+		Elems []VectorElem `json:"elems"`
 	}
 	UnaryExpr struct {
 		Kind    string `json:"kind" unpack:""`
@@ -93,11 +93,17 @@ type (
 		Exprs []Expr      `json:"exprs"`
 		Scope *Sequential `json:"scope"`
 	}
+	VectorElem interface {
+		vectorElem()
+	}
 )
 
 func (*Field) recordAST()  {}
 func (*Spread) recordAST() {}
 
+func (*Spread) vectorElem()      {}
+func (*VectorValue) vectorElem() {}
+
 // Various Expr fields.
 
 type (
@@ -114,6 +120,10 @@ type (
 		Key   Expr `json:"key"`
 		Value Expr `json:"value"`
 	}
+	VectorValue struct {
+		Kind string `json:"kind" unpack:""`
+		Expr Expr   `json:"expr"`
+	}
 )
 
 func (*Agg) ExprDAG()          {}
