@@ -4,12 +4,25 @@ import (
 	"errors"
 
 	"github.com/brimdata/zed/compiler/ast"
+	"github.com/brimdata/zed/compiler/data"
+	"github.com/brimdata/zed/lakeparse"
+	"github.com/brimdata/zed/pkg/storage"
+	"github.com/brimdata/zed/runtime"
 	"github.com/brimdata/zed/runtime/op"
 	"github.com/brimdata/zed/zio"
 )
 
-func CompileForFileSystem(pctx *op.Context, o ast.Op, readers []zio.Reader, adaptor op.DataAdaptor) (*Runtime, error) {
-	runtime, err := New(pctx, o, adaptor, nil)
+type fsCompiler struct {
+	anyCompiler
+	src *data.Source
+}
+
+func NewFileSystemCompiler(engine storage.Engine) runtime.Compiler {
+	return &fsCompiler{src: data.NewSource(engine, nil)}
+}
+
+func (f *fsCompiler) NewQuery(pctx *op.Context, o ast.Op, readers []zio.Reader) (*runtime.Query, error) {
+	job, err := NewJob(pctx, o, f.src, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -17,15 +30,15 @@ func CompileForFileSystem(pctx *op.Context, o ast.Op, readers []zio.Reader, adap
 		if len(readers) != 2 {
 			return nil, errors.New("join operaetor requires two inputs")
 		}
-		if len(runtime.readers) != 2 {
+		if len(job.readers) != 2 {
 			return nil, errors.New("internal error: join expected by semantic analyzer")
 		}
-		runtime.readers[0].Readers = readers[0:1]
-		runtime.readers[1].Readers = readers[1:2]
+		job.readers[0].Readers = readers[0:1]
+		job.readers[1].Readers = readers[1:2]
 	} else if len(readers) == 0 {
 		// If there's no reader but the DAG wants an input, then
 		// flag an error.
-		if len(runtime.readers) != 0 {
+		if len(job.readers) != 0 {
 			return nil, errors.New("no input specified: use a command-line file or a Zed source operator")
 		}
 	} else {
@@ -34,15 +47,19 @@ func CompileForFileSystem(pctx *op.Context, o ast.Op, readers []zio.Reader, adap
 		// TBD: we could have such a configuration is a composite
 		// from command includes a "pass" operator, but we can add this later.
 		// See issue #2640.
-		if len(runtime.readers) == 0 {
+		if len(job.readers) == 0 {
 			return nil, errors.New("redundant inputs specified: use either command-line files or a Zed source operator")
 		}
-		if len(runtime.readers) != 1 {
+		if len(job.readers) != 1 {
 			return nil, errors.New("Zed query requires a single input path")
 		}
-		runtime.readers[0].Readers = readers
+		job.readers[0].Readers = readers
 	}
-	return optimizeAndBuild(runtime)
+	return optimizeAndBuild(job)
+}
+
+func (*fsCompiler) NewLakeQuery(pctx *op.Context, program ast.Op, parallelism int, head *lakeparse.Commitish) (*runtime.Query, error) {
+	panic("NewLakeQuery called on compiler.fsCompiler")
 }
 
 func isJoin(o ast.Op) bool {
@@ -54,18 +71,18 @@ func isJoin(o ast.Op) bool {
 	return ok
 }
 
-func optimizeAndBuild(runtime *Runtime) (*Runtime, error) {
+func optimizeAndBuild(job *Job) (*runtime.Query, error) {
 	// Call optimize to possible push down a filter predicate into the
 	// kernel.Reader so that the zng scanner can do boyer-moore.
-	if err := runtime.Optimize(); err != nil {
+	if err := job.Optimize(); err != nil {
 		return nil, err
 	}
 	// For an internal reader (like a shaper on intake), we don't do
 	// any parallelization right now though this could be potentially
 	// beneficial depending on where the bottleneck is for a given shaper.
 	// See issue #2641.
-	if err := runtime.Build(); err != nil {
+	if err := job.Build(); err != nil {
 		return nil, err
 	}
-	return runtime, nil
+	return runtime.NewQuery(job.pctx, job.Puller(), job.builder.Meters()), nil
 }
