@@ -7,8 +7,10 @@ import (
 
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/compiler/ast/dag"
+	"github.com/brimdata/zed/compiler/data"
 	"github.com/brimdata/zed/order"
 	"github.com/brimdata/zed/pkg/field"
+	"github.com/brimdata/zed/runtime/exec"
 	"github.com/brimdata/zed/runtime/expr"
 	"github.com/brimdata/zed/runtime/expr/extent"
 	"github.com/brimdata/zed/runtime/op"
@@ -38,16 +40,16 @@ import (
 var ErrJoinParents = errors.New("join requires two upstream parallel query paths")
 
 type Builder struct {
-	pctx       *op.Context
-	adaptor    op.DataAdaptor
-	schedulers map[dag.Source]op.Scheduler
+	pctx     *op.Context
+	source   *data.Source
+	planners map[dag.Source]from.Planner
 }
 
-func NewBuilder(pctx *op.Context, adaptor op.DataAdaptor) *Builder {
+func NewBuilder(pctx *op.Context, source *data.Source) *Builder {
 	return &Builder{
-		pctx:       pctx,
-		adaptor:    adaptor,
-		schedulers: make(map[dag.Source]op.Scheduler),
+		pctx:     pctx,
+		source:   source,
+		planners: make(map[dag.Source]from.Planner),
 	}
 }
 
@@ -73,8 +75,8 @@ func (b *Builder) zctx() *zed.Context {
 
 func (b *Builder) Meters() []zbuf.Meter {
 	var meters []zbuf.Meter
-	for _, sched := range b.schedulers {
-		meters = append(meters, sched)
+	for _, planner := range b.planners {
+		meters = append(meters, planner)
 	}
 	return meters
 }
@@ -148,7 +150,7 @@ func (b *Builder) compileLeaf(o dag.Op, parent zbuf.Puller) (zbuf.Puller, error)
 		if err != nil {
 			return nil, fmt.Errorf("compiling top: %w", err)
 		}
-		return top.New(parent, b.pctx.Zctx, v.Limit, fields, v.Flush), nil
+		return top.New(b.pctx.Zctx, parent, v.Limit, fields, v.Flush), nil
 	case *dag.Put:
 		clauses, err := b.compileAssignments(v.Args)
 		if err != nil {
@@ -519,71 +521,72 @@ func (b *Builder) compileTrunk(trunk *dag.Trunk, parent zbuf.Puller) ([]zbuf.Pul
 			filter:  pushdown,
 			readers: src.Readers,
 		}
-		source = from.NewScheduler(b.pctx, sched)
-		b.schedulers[src] = sched
+		source = from.New(b.pctx, sched)
+		b.planners[src] = sched
 	case *dag.Pass:
 		source = parent
 	case *dag.Pool:
-		// We keep a map of schedulers indexed by *dag.Pool so we
-		// properly share parallel instances of a given scheduler
-		// across different DAG entry points.  The scanners from a
-		// common lake.ScanScheduler are distributed across the collection
-		// of op.From operators.
-		sched, ok := b.schedulers[src]
+		// We keep a map of planners indexed by *dag.Pool so we
+		// properly share parallel instances of a given planner
+		// across different DAG entry points.  The planners from a
+		// common exec.Planner are distributed across the collection
+		// of op.From operators and the planner distributes work across
+		// the parallel instances of trunks.
+		planner, ok := b.planners[src]
 		if !ok {
 			span, err := b.compileRange(src, src.ScanLower, src.ScanUpper)
 			if err != nil {
 				return nil, err
 			}
-			sched, err = b.adaptor.NewScheduler(b.pctx.Context, b.pctx.Zctx, src, span, pushdown)
+			planner, err = exec.NewPlannerByID(b.pctx.Context, b.pctx.Zctx, b.source.Lake(), src.ID, src.Commit, span, pushdown)
 			if err != nil {
 				return nil, err
 			}
-			b.schedulers[src] = sched
+			b.planners[src] = planner
 		}
-		source = from.NewScheduler(b.pctx, sched)
+		source = from.New(b.pctx, planner)
 	case *dag.PoolMeta:
-		sched, ok := b.schedulers[src]
+		planner, ok := b.planners[src]
 		if !ok {
-			sched, err = b.adaptor.NewScheduler(b.pctx.Context, b.pctx.Zctx, src, nil, pushdown)
+			planner, err = exec.NewPoolMetaPlanner(b.pctx.Context, b.pctx.Zctx, b.source.Lake(), src.ID, src.Meta, pushdown)
 			if err != nil {
 				return nil, err
 			}
-			b.schedulers[src] = sched
+			b.planners[src] = planner
 		}
-		source = from.NewScheduler(b.pctx, sched)
+		source = from.New(b.pctx, planner)
 	case *dag.CommitMeta:
-		sched, ok := b.schedulers[src]
+		planner, ok := b.planners[src]
 		if !ok {
 			span, err := b.compileRange(src, src.ScanLower, src.ScanUpper)
 			if err != nil {
 				return nil, err
 			}
-			sched, err = b.adaptor.NewScheduler(b.pctx.Context, b.pctx.Zctx, src, span, pushdown)
+			planner, err = exec.NewCommitMetaPlanner(b.pctx.Context, b.pctx.Zctx, b.source.Lake(), src.Pool, src.Commit, src.Meta, span, pushdown)
 			if err != nil {
 				return nil, err
 			}
-			b.schedulers[src] = sched
+			b.planners[src] = planner
 		}
-		source = from.NewScheduler(b.pctx, sched)
+		source = from.New(b.pctx, planner)
 	case *dag.LakeMeta:
-		sched, ok := b.schedulers[src]
+		planner, ok := b.planners[src]
 		if !ok {
-			sched, err = b.adaptor.NewScheduler(b.pctx.Context, b.pctx.Zctx, src, nil, pushdown)
+			planner, err = exec.NewLakeMetaPlanner(b.pctx.Context, b.pctx.Zctx, b.source.Lake(), src.Meta, pushdown)
 			if err != nil {
 				return nil, err
 			}
-			b.schedulers[src] = sched
+			b.planners[src] = planner
 		}
-		source = from.NewScheduler(b.pctx, sched)
+		source = from.New(b.pctx, planner)
 	case *dag.HTTP:
-		puller, err := b.adaptor.Open(b.pctx.Context, b.pctx.Zctx, src.URL, src.Format, pushdown)
+		puller, err := b.source.Open(b.pctx.Context, b.pctx.Zctx, src.URL, src.Format, pushdown)
 		if err != nil {
 			return nil, err
 		}
 		source = from.NewPuller(b.pctx, puller)
 	case *dag.File:
-		scanner, err := b.adaptor.Open(b.pctx.Context, b.pctx.Zctx, src.Path, src.Format, pushdown)
+		scanner, err := b.source.Open(b.pctx.Context, b.pctx.Zctx, src.Path, src.Format, pushdown)
 		if err != nil {
 			return nil, err
 		}
@@ -616,7 +619,7 @@ func (b *Builder) compileRange(src dag.Source, exprLower, exprUpper dag.Expr) (e
 	}
 	var span extent.Span
 	if lower.Bytes != nil || upper.Bytes != nil {
-		layout := b.adaptor.Layout(b.pctx.Context, src)
+		layout := b.source.Layout(b.pctx.Context, src)
 		span = extent.NewGenericFromOrder(*lower, *upper, layout.Order)
 	}
 	return span, nil
@@ -666,7 +669,7 @@ type readerScheduler struct {
 	progress zbuf.Progress
 }
 
-func (r *readerScheduler) PullScanTask() (zbuf.Puller, error) {
+func (r *readerScheduler) PullWork() (zbuf.Puller, error) {
 	if r.scanner != nil {
 		r.progress.Add(r.scanner.Progress())
 		r.scanner = nil
