@@ -190,22 +190,22 @@ func semExpr(scope *Scope, e ast.Expr) (dag.Expr, error) {
 			Elems: out,
 		}, nil
 	case *ast.ArrayExpr:
-		exprs, err := semExprs(scope, e.Exprs)
+		elems, err := semVectorElems(scope, e.Elems)
 		if err != nil {
 			return nil, err
 		}
 		return &dag.ArrayExpr{
 			Kind:  "ArrayExpr",
-			Exprs: exprs,
+			Elems: elems,
 		}, nil
 	case *ast.SetExpr:
-		exprs, err := semExprs(scope, e.Exprs)
+		elems, err := semVectorElems(scope, e.Elems)
 		if err != nil {
 			return nil, err
 		}
 		return &dag.SetExpr{
 			Kind:  "SetExpr",
-			Exprs: exprs,
+			Elems: elems,
 		}, nil
 	case *ast.MapExpr:
 		var entries []dag.Entry
@@ -660,3 +660,24 @@ func semType(scope *Scope, typ astzed.Type) (string, error) {
 	}
 	return zson.FormatType(ztype), nil
 }
+
+func semVectorElems(scope *Scope, elems []ast.VectorElem) ([]dag.VectorElem, error) {
+	var out []dag.VectorElem
+	for _, elem := range elems {
+		switch elem := elem.(type) {
+		case *ast.Spread:
+			e, err := semExpr(scope, elem.Expr)
+			if err != nil {
+				return nil, err
+			}
+			out = append(out, &dag.Spread{Kind: "Spread", Expr: e})
+		case *ast.VectorValue:
+			e, err := semExpr(scope, elem.Expr)
+			if err != nil {
+				return nil, err
+			}
+			out = append(out, &dag.VectorValue{Kind: "VectorValue", Expr: e})
+		}
+	}
+	return out, nil
+}
