@@ -14,14 +14,16 @@ import (
 	"github.com/brimdata/zed/pkg/rlimit"
 	"github.com/brimdata/zed/pkg/storage"
 	"github.com/brimdata/zed/runtime"
+	"github.com/brimdata/zed/runtime/exec"
 	"github.com/brimdata/zed/zbuf"
 	"github.com/brimdata/zed/zio"
 	"github.com/segmentio/ksuid"
 )
 
 type local struct {
-	root   *lake.Root
-	engine storage.Engine
+	root     *lake.Root
+	compiler runtime.Compiler
+	engine   storage.Engine
 }
 
 var _ Interface = (*local)(nil)
@@ -37,8 +39,9 @@ func OpenLocalLake(ctx context.Context, lakePath string) (Interface, error) {
 		return nil, err
 	}
 	return &local{
-		root:   root,
-		engine: engine,
+		root:     root,
+		compiler: compiler.NewLakeCompiler(root),
+		engine:   engine,
 	}, nil
 }
 
@@ -58,6 +61,10 @@ func CreateLocalLake(ctx context.Context, lakePath string) (Interface, error) {
 	}, nil
 }
 
+func (l *local) Root() *lake.Root {
+	return l.root
+}
+
 func (l *local) CreatePool(ctx context.Context, name string, layout order.Layout, seekStride int, thresh int64) (ksuid.KSUID, error) {
 	if name == "" {
 		return ksuid.Nil, errors.New("no pool name provided")
@@ -94,6 +101,14 @@ func (l *local) MergeBranch(ctx context.Context, poolID ksuid.KSUID, childBranch
 	return l.root.MergeBranch(ctx, poolID, childBranch, parentBranch, message.Author, message.Body)
 }
 
+func (l *local) Compact(ctx context.Context, poolID ksuid.KSUID, branchName string, objects []ksuid.KSUID, commit api.CommitMessage) (ksuid.KSUID, error) {
+	pool, err := l.root.OpenPool(ctx, poolID)
+	if err != nil {
+		return ksuid.Nil, err
+	}
+	return exec.Compact(ctx, pool, branchName, objects, commit.Author, commit.Body, commit.Meta)
+}
+
 func (l *local) AddIndexRules(ctx context.Context, rules []index.Rule) error {
 	return l.root.AddIndexRules(ctx, rules)
 }
@@ -111,14 +126,14 @@ func (l *local) Query(ctx context.Context, head *lakeparse.Commitish, src string
 }
 
 func (l *local) QueryWithControl(ctx context.Context, head *lakeparse.Commitish, src string, srcfiles ...string) (zbuf.ProgressReadCloser, error) {
-	flowgraph, err := compiler.ParseOp(src, srcfiles...)
+	flowgraph, err := l.compiler.Parse(src, srcfiles...)
 	if err != nil {
 		return nil, err
 	}
 	if _, err := rlimit.RaiseOpenFilesLimit(); err != nil {
 		return nil, err
 	}
-	q, err := runtime.NewQueryOnLake(ctx, zed.NewContext(), flowgraph, l.root, head, nil)
+	q, err := runtime.CompileLakeQuery(ctx, zed.NewContext(), l.compiler, flowgraph, head, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -173,7 +188,7 @@ func (l *local) DeleteByPredicate(ctx context.Context, poolID ksuid.KSUID, branc
 	if err != nil {
 		return ksuid.Nil, err
 	}
-	return branch.DeleteByPredicate(ctx, l.root, src, commit.Author, commit.Body, commit.Meta)
+	return branch.DeleteByPredicate(ctx, l.compiler, src, commit.Author, commit.Body, commit.Meta)
 }
 
 func (l *local) Revert(ctx context.Context, poolID ksuid.KSUID, branchName string, commitID ksuid.KSUID, message api.CommitMessage) (ksuid.KSUID, error) {
@@ -193,7 +208,7 @@ func (l *local) ApplyIndexRules(ctx context.Context, name string, poolID ksuid.K
 	if err != nil {
 		return ksuid.Nil, err
 	}
-	commit, err := branch.ApplyIndexRules(ctx, rules, tags)
+	commit, err := branch.ApplyIndexRules(ctx, l.compiler, rules, tags)
 	if err != nil {
 		return ksuid.Nil, err
 	}
@@ -214,5 +229,5 @@ func (l *local) UpdateIndex(ctx context.Context, names []string, poolID ksuid.KS
 	if err != nil {
 		return ksuid.Nil, err
 	}
-	return branch.UpdateIndex(ctx, rules)
+	return branch.UpdateIndex(ctx, l.compiler, rules)
 }
