@@ -9,6 +9,7 @@ import (
 	"github.com/brimdata/zed/api"
 	"github.com/brimdata/zed/api/client"
 	"github.com/brimdata/zed/api/queryio"
+	"github.com/brimdata/zed/lake"
 	"github.com/brimdata/zed/lake/index"
 	"github.com/brimdata/zed/lakeparse"
 	"github.com/brimdata/zed/order"
@@ -28,6 +29,10 @@ func NewRemoteLake(conn *client.Connection) Interface {
 	return &remote{conn}
 }
 
+func (l *remote) Root() *lake.Root {
+	return nil
+}
+
 func (r *remote) PoolID(ctx context.Context, poolName string) (ksuid.KSUID, error) {
 	config, err := LookupPoolByName(ctx, r, poolName)
 	if err != nil {
@@ -71,6 +76,11 @@ func (r *remote) MergeBranch(ctx context.Context, poolID ksuid.KSUID, childBranc
 	return res.Commit, err
 }
 
+func (r *remote) Compact(ctx context.Context, poolID ksuid.KSUID, branch string, objects []ksuid.KSUID, commit api.CommitMessage) (ksuid.KSUID, error) {
+	res, err := r.conn.Compact(ctx, poolID, branch, objects, commit)
+	return res.Commit, err
+}
+
 func (r *remote) RemovePool(ctx context.Context, pool ksuid.KSUID) error {
 	return r.conn.RemovePool(ctx, pool)
 }
@@ -84,8 +94,8 @@ func (r *remote) RenamePool(ctx context.Context, pool ksuid.KSUID, name string)
 
 func (r *remote) Load(ctx context.Context, _ *zed.Context, poolID ksuid.KSUID, branchName string, reader zio.Reader, commit api.CommitMessage) (ksuid.KSUID, error) {
 	pr, pw := io.Pipe()
-	w := zngio.NewWriter(pw, zngio.WriterOpts{LZ4BlockSize: zngio.DefaultLZ4BlockSize})
 	go func() {
+		w := zngio.NewWriter(pw)
 		zio.CopyWithContext(ctx, w, reader)
 		w.Close()
 	}()
