@@ -7,17 +7,14 @@ import (
 	"strings"
 
 	"github.com/brimdata/zed"
-	"github.com/brimdata/zed/compiler"
 	"github.com/brimdata/zed/lake/branches"
 	"github.com/brimdata/zed/lake/commits"
 	"github.com/brimdata/zed/lake/data"
 	"github.com/brimdata/zed/lake/index"
 	"github.com/brimdata/zed/lake/journal"
-	"github.com/brimdata/zed/pkg/nano"
+	"github.com/brimdata/zed/order"
 	"github.com/brimdata/zed/pkg/storage"
 	"github.com/brimdata/zed/runtime"
-	"github.com/brimdata/zed/runtime/expr/extent"
-	"github.com/brimdata/zed/runtime/op"
 	"github.com/brimdata/zed/zbuf"
 	"github.com/brimdata/zed/zio"
 	"github.com/brimdata/zed/zio/zngio"
@@ -127,13 +124,13 @@ func (b *Branch) Delete(ctx context.Context, ids []ksuid.KSUID, author, message
 	})
 }
 
-func (b *Branch) DeleteByPredicate(ctx context.Context, lake op.DataAdaptor, src string, author, message, meta string) (ksuid.KSUID, error) {
+func (b *Branch) DeleteByPredicate(ctx context.Context, c runtime.Compiler, src string, author, message, meta string) (ksuid.KSUID, error) {
 	zctx := zed.NewContext()
 	appMeta, err := loadMeta(zctx, meta)
 	if err != nil {
 		return ksuid.Nil, err
 	}
-	val, op, err := compiler.ParseRangeExpr(zctx, src, b.pool.Layout)
+	val, op, err := c.ParseRangeExpr(zctx, src, b.pool.Layout)
 	if err != nil {
 		return ksuid.Nil, err
 	}
@@ -142,7 +139,7 @@ func (b *Branch) DeleteByPredicate(ctx context.Context, lake op.DataAdaptor, src
 		if err != nil {
 			return nil, err
 		}
-		copies, deletes, err := b.getDbpObjects(ctx, lake, val, op, parent.Commit)
+		copies, deletes, err := b.getDbpObjects(ctx, c, val, op, parent.Commit)
 		if err != nil {
 			return nil, err
 		}
@@ -151,7 +148,7 @@ func (b *Branch) DeleteByPredicate(ctx context.Context, lake op.DataAdaptor, src
 			return nil, errors.New("nothing to delete")
 		}
 		// XXX Copied should be deleted if the commit fails.
-		copied, err := b.dbpCopies(ctx, base, copies, src)
+		copied, err := b.dbpCopies(ctx, c, base, copies, src)
 		if err != nil {
 			return nil, err
 		}
@@ -174,7 +171,7 @@ func (b *Branch) DeleteByPredicate(ctx context.Context, lake op.DataAdaptor, src
 	})
 }
 
-func (b *Branch) dbpCopies(ctx context.Context, snap *commits.Snapshot, copies []ksuid.KSUID, filter string) ([]data.Object, error) {
+func (b *Branch) dbpCopies(ctx context.Context, c runtime.Compiler, snap *commits.Snapshot, copies []ksuid.KSUID, filter string) ([]data.Object, error) {
 	if len(copies) == 0 {
 		return nil, nil
 	}
@@ -192,22 +189,21 @@ func (b *Branch) dbpCopies(ctx context.Context, snap *commits.Snapshot, copies [
 		// leverage the seek index to skip over irrelavant segments but we don't
 		// have a way to translate the delete filter into an extent.Span, so
 		// just read the whole file.
-		objectPath := o.RowObjectPath(b.pool.DataPath)
-		reader, err := b.pool.engine.Get(ctx, objectPath)
+		reader, err := b.pool.engine.Get(ctx, o.SequenceURI(b.pool.DataPath))
 		if err != nil {
 			return nil, err
 		}
 		defer reader.Close()
-		readers[i] = zngio.NewReader(reader, zctx)
+		readers[i] = zngio.NewReader(zctx, reader)
 		defer readers[i].(*zngio.Reader).Close()
 	}
 	// Keeps values that don't fit the filter by adding "not".
-	flowgraph, err := compiler.ParseOp("not " + filter)
+	flowgraph, err := c.Parse("not " + filter)
 	if err != nil {
 		return nil, err
 	}
 	r := zio.NewCombiner(ctx, readers)
-	q, err := runtime.NewQueryOnReader(ctx, zctx, flowgraph, r, nil)
+	q, err := runtime.CompileQuery(ctx, zctx, c, flowgraph, []zio.Reader{r})
 	if err != nil {
 		return nil, err
 	}
@@ -231,14 +227,14 @@ func (b *Branch) dbpCopies(ctx context.Context, snap *commits.Snapshot, copies [
 
 // getDbpObjects gets the object IDs of objects effected by a delete by predicate
 // operation.
-func (b *Branch) getDbpObjects(ctx context.Context, lake op.DataAdaptor, val *zed.Value, op string, commit ksuid.KSUID) ([]ksuid.KSUID, []ksuid.KSUID, error) {
+func (b *Branch) getDbpObjects(ctx context.Context, c runtime.Compiler, val *zed.Value, op string, commit ksuid.KSUID) ([]ksuid.KSUID, []ksuid.KSUID, error) {
 	const dbp = `
 const THRESH = %s
 from %s@%s:objects
 | {
 	id: id,
-	lower: compare(meta.first, meta.last) < 0 ? meta.first : meta.last,
-	upper: compare(meta.first, meta.last) < 0 ? meta.last : meta.first
+	lower: compare(meta.first, meta.last, %t) < 0 ? meta.first : meta.last,
+	upper: compare(meta.first, meta.last, %t) < 0 ? meta.last : meta.first
   }
 | switch (
   case %s %s THRESH => deletes:=collect(id)
@@ -248,12 +244,13 @@ from %s@%s:objects
 	if op == ">=" || op == ">" {
 		deletesField, copiesField = copiesField, deletesField
 	}
-	src := fmt.Sprintf(dbp, zson.MustFormatValue(val), b.pool.ID, commit, deletesField, op, copiesField, op)
-	flowgraph, err := compiler.ParseOp(src)
+	nullsMax := b.pool.Layout.Order == order.Asc
+	src := fmt.Sprintf(dbp, zson.MustFormatValue(val), b.pool.ID, commit, nullsMax, nullsMax, deletesField, op, copiesField, op)
+	flowgraph, err := c.Parse(src)
 	if err != nil {
 		return nil, nil, err
 	}
-	q, err := runtime.NewQueryOnLake(ctx, zed.NewContext(), flowgraph, lake, nil, nil)
+	q, err := runtime.CompileLakeQuery(ctx, zed.NewContext(), c, flowgraph, nil, nil)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -299,6 +296,36 @@ func (b *Branch) Revert(ctx context.Context, commit ksuid.KSUID, author, message
 	})
 }
 
+func (b *Branch) CommitCompact(ctx context.Context, src, rollup []*data.Object, author, message, meta string) (ksuid.KSUID, error) {
+	if len(rollup) < 1 {
+		return ksuid.Nil, errors.New("compact: one or more rollup objects required")
+	}
+	zctx := zed.NewContext()
+	appMeta, err := loadMeta(zctx, meta)
+	if err != nil {
+		return ksuid.Nil, err
+	}
+	return b.commit(ctx, func(parent *branches.Config, retries int) (*commits.Object, error) {
+		base, err := b.pool.commits.Snapshot(ctx, parent.Commit)
+		if err != nil {
+			return nil, err
+		}
+		patch := commits.NewPatch(base)
+		for _, o := range rollup {
+			if err := patch.AddDataObject(o); err != nil {
+				return nil, err
+			}
+		}
+		for _, o := range src {
+			if err := patch.DeleteObject(o.ID); err != nil {
+				return nil, err
+			}
+		}
+		commit := patch.NewCommitObject(parent.Commit, retries, author, message, *appMeta)
+		return commit, nil
+	})
+}
+
 func (b *Branch) mergeInto(ctx context.Context, parent *Branch, author, message string) (ksuid.KSUID, error) {
 	if b == parent {
 		return ksuid.Nil, errors.New("cannot merge branch into itself")
@@ -346,14 +373,17 @@ func (b *Branch) buildMergeObject(ctx context.Context, parent *branches.Config,
 	if err != nil {
 		return nil, err
 	}
-	if overlap := childPatch.OverlappingDeletes(parentPatch); overlap != nil {
-		//XXX add IDs of (some of the) overlaps
-		return nil, errors.New("write conflict on merge")
-	}
 	if message == "" {
-		message = fmt.Sprintf("merged %s into %s", b.Name, parent.Name)
+		message = fmt.Sprintf("merged %q into %q", b.Name, parent.Name)
 	}
-	return childPatch.NewCommitObject(parent.Commit, retries, author, message, zed.Value{zed.TypeNull, nil}), nil
+	// Now compute the diff between the parent patch and the child patch so that
+	// the diff patch will reflect the changes from the child into the parent.
+	// Diff() will also check for delete conflicts.
+	diff, err := commits.Diff(parentPatch, childPatch)
+	if err != nil {
+		return nil, fmt.Errorf("error merging %q into %q: %w", b.Name, parent.Name, err)
+	}
+	return diff.NewCommitObject(parent.Commit, retries, author, message, zed.Value{zed.TypeNull, nil}), nil
 }
 
 func commonAncestor(a, b []ksuid.KSUID) ksuid.KSUID {
@@ -446,32 +476,32 @@ func (b *Branch) Pool() *Pool {
 	return b.pool
 }
 
-func (b *Branch) ApplyIndexRules(ctx context.Context, rules []index.Rule, ids []ksuid.KSUID) (ksuid.KSUID, error) {
+func (b *Branch) ApplyIndexRules(ctx context.Context, c runtime.Compiler, rules []index.Rule, ids []ksuid.KSUID) (ksuid.KSUID, error) {
 	idxrefs := make([]*index.Object, 0, len(rules)*len(ids))
 	for _, id := range ids {
 		//XXX make issue for this.
 		// This could be easily parallized with errgroup.
-		refs, err := b.indexObject(ctx, rules, id)
+		refs, err := b.indexObject(ctx, c, rules, id)
 		if err != nil {
 			return ksuid.Nil, err
 		}
 		idxrefs = append(idxrefs, refs...)
 	}
 	author := "indexer"
-	message := index_message(rules)
+	message := indexMessage(rules)
 	return b.commit(ctx, func(parent *branches.Config, retries int) (*commits.Object, error) {
 		return commits.NewAddIndexesObject(parent.Commit, author, message, retries, idxrefs), nil
 	})
 }
 
-func (b *Branch) UpdateIndex(ctx context.Context, rules []index.Rule) (ksuid.KSUID, error) {
+func (b *Branch) UpdateIndex(ctx context.Context, c runtime.Compiler, rules []index.Rule) (ksuid.KSUID, error) {
 	snap, err := b.pool.commits.Snapshot(ctx, b.Commit)
 	if err != nil {
 		return ksuid.Nil, err
 	}
 	var objects []*index.Object
 	for id, rules := range snap.Unindexed(rules) {
-		o, err := b.indexObject(ctx, rules, id)
+		o, err := b.indexObject(ctx, c, rules, id)
 		if err != nil {
 			return ksuid.Nil, err
 		}
@@ -481,13 +511,13 @@ func (b *Branch) UpdateIndex(ctx context.Context, rules []index.Rule) (ksuid.KSU
 		return ksuid.Nil, commits.ErrEmptyTransaction
 	}
 	const author = "indexer"
-	message := index_message(rules)
+	message := indexMessage(rules)
 	return b.commit(ctx, func(parent *branches.Config, retries int) (*commits.Object, error) {
 		return commits.NewAddIndexesObject(parent.Commit, author, message, retries, objects), nil
 	})
 }
 
-func index_message(rules []index.Rule) string {
+func indexMessage(rules []index.Rule) string {
 	skip := make(map[string]struct{})
 	var names []string
 	for _, r := range rules {
@@ -503,14 +533,14 @@ func index_message(rules []index.Rule) string {
 	return "index rules applied: " + strings.Join(names, ",")
 }
 
-func (b *Branch) indexObject(ctx context.Context, rules []index.Rule, id ksuid.KSUID) ([]*index.Object, error) {
-	r, err := b.engine.Get(ctx, data.RowObjectPath(b.pool.DataPath, id))
+func (b *Branch) indexObject(ctx context.Context, c runtime.Compiler, rules []index.Rule, id ksuid.KSUID) ([]*index.Object, error) {
+	r, err := b.engine.Get(ctx, data.SequenceURI(b.pool.DataPath, id))
 	if err != nil {
 		return nil, err
 	}
-	reader := zngio.NewReader(r, zed.NewContext())
+	reader := zngio.NewReader(zed.NewContext(), r)
 	defer reader.Close()
-	w, err := index.NewCombiner(ctx, b.engine, b.pool.IndexPath, rules, id)
+	w, err := index.NewCombiner(ctx, c, b.engine, b.pool.IndexPath, rules, id)
 	if err != nil {
 		r.Close()
 		return nil, err
@@ -526,45 +556,3 @@ func (b *Branch) indexObject(ctx context.Context, rules []index.Rule, id ksuid.K
 	}
 	return w.References(), err
 }
-
-type BranchStats struct {
-	Size int64 `zed:"size"`
-	// XXX (nibs) - This shouldn't be a span because keys don't have to be time.
-	Span *nano.Span `zed:"span"`
-}
-
-func (b *Branch) Stats(ctx context.Context, snap commits.View) (info BranchStats, err error) {
-	ch := make(chan data.Object)
-	ctx, cancel := context.WithCancel(ctx)
-	defer cancel()
-	go func() {
-		err = ScanSpan(ctx, snap, nil, b.pool.Layout.Order, ch)
-		close(ch)
-	}()
-	// XXX this doesn't scale... it should be stored in the snapshot and is
-	// not easy to compute in the face of deletes...
-	var poolSpan *extent.Generic
-	for object := range ch {
-		info.Size += object.Size
-		if poolSpan == nil {
-			poolSpan = extent.NewGenericFromOrder(object.First, object.Last, b.pool.Layout.Order)
-		} else {
-			poolSpan.Extend(&object.First)
-			poolSpan.Extend(&object.Last)
-		}
-	}
-	//XXX need to change API to take return key range
-	if poolSpan != nil {
-		min := poolSpan.First()
-		if min.Type == zed.TypeTime {
-			firstTs := zed.DecodeTime(min.Bytes)
-			lastTs := zed.DecodeTime(poolSpan.Last().Bytes)
-			if lastTs < firstTs {
-				firstTs, lastTs = lastTs, firstTs
-			}
-			span := nano.NewSpanTs(firstTs, lastTs+1)
-			info.Span = &span
-		}
-	}
-	return info, err
-}
