@@ -307,7 +307,7 @@ func (p *Putter) Eval(ectx Context, this *zed.Value) *zed.Value {
 			// propagate errors
 			return this
 		}
-		return ectx.CopyValue(*p.zctx.NewErrorf("put: not a record: %s", zson.MustFormatValue(*this)))
+		return ectx.CopyValue(p.zctx.NewErrorf("put: not a record: %s", zson.MustFormatValue(this)))
 	}
 	vals, clauses := p.eval(ectx, this)
 	if len(vals) == 0 {
