@@ -57,8 +57,8 @@ func (s *Shaper) Eval(ectx Context, this *zed.Value) *zed.Value {
 	}
 	//XXX TypeUnder?
 	if typeVal.Type != zed.TypeType {
-		return ectx.CopyValue(*s.zctx.NewErrorf(
-			"shaper type argument is not a type: %s", zson.MustFormatValue(*typeVal)))
+		return ectx.CopyValue(s.zctx.NewErrorf(
+			"shaper type argument is not a type: %s", zson.MustFormatValue(typeVal)))
 	}
 	shapeTo, err := s.zctx.LookupByValue(typeVal.Bytes)
 	if err != nil {
@@ -107,7 +107,7 @@ func (c *ConstShaper) Eval(ectx Context, this *zed.Value) *zed.Value {
 		var err error
 		s, err = newShaper(c.zctx, c.transforms, val.Type, c.shapeTo)
 		if err != nil {
-			return ectx.CopyValue(*c.zctx.NewError(err))
+			return ectx.CopyValue(c.zctx.NewError(err))
 		}
 		c.shapers[id] = s
 	}
