@@ -13,6 +13,7 @@ import (
 	lakeapi "github.com/brimdata/zed/lake/api"
 	"github.com/brimdata/zed/lake/branches"
 	"github.com/brimdata/zed/lake/pools"
+	"github.com/brimdata/zed/runtime/exec"
 	"github.com/brimdata/zed/zio"
 	"github.com/brimdata/zed/zio/zngio"
 	"github.com/brimdata/zed/zio/zsonio"
@@ -26,7 +27,7 @@ type testClient struct {
 	*client.Connection
 }
 
-func (c *testClient) TestPoolStats(id ksuid.KSUID) lake.PoolStats {
+func (c *testClient) TestPoolStats(id ksuid.KSUID) exec.PoolStats {
 	r, err := c.Connection.PoolStats(context.Background(), id)
 	require.NoError(c, err)
 	return r
@@ -51,7 +52,7 @@ func (c *testClient) TestPoolList() []pools.Config {
 	require.NoError(c, err)
 	defer r.Body.Close()
 	var confs []pools.Config
-	zr := zngio.NewReader(r.Body, zed.NewContext())
+	zr := zngio.NewReader(zed.NewContext(), r.Body)
 	defer zr.Close()
 	for {
 		rec, err := zr.Read()
@@ -82,7 +83,7 @@ func (c *testClient) TestQuery(query string) string {
 	r, err := c.Connection.Query(context.Background(), nil, query)
 	require.NoError(c, err)
 	defer r.Body.Close()
-	zr := zngio.NewReader(r.Body, zed.NewContext())
+	zr := zngio.NewReader(zed.NewContext(), r.Body)
 	defer zr.Close()
 	var buf bytes.Buffer
 	zw := zsonio.NewWriter(zio.NopCloser(&buf), zsonio.WriterOpts{})
