@@ -14,8 +14,10 @@ import (
 	"time"
 
 	"github.com/brimdata/zed/api"
+	"github.com/brimdata/zed/compiler"
 	"github.com/brimdata/zed/lake"
 	"github.com/brimdata/zed/pkg/storage"
+	"github.com/brimdata/zed/runtime"
 	"github.com/brimdata/zed/zson"
 	"github.com/gorilla/mux"
 	"github.com/prometheus/client_golang/prometheus"
@@ -50,6 +52,7 @@ type Config struct {
 
 type Core struct {
 	auth            *Auth0Authenticator
+	compiler        runtime.Compiler
 	conf            Config
 	engine          storage.Engine
 	logger          *zap.Logger
@@ -132,6 +135,7 @@ func NewCore(ctx context.Context, conf Config) (*Core, error) {
 
 	c := &Core{
 		auth:          authenticator,
+		compiler:      compiler.NewLakeCompiler(root),
 		conf:          conf,
 		engine:        engine,
 		logger:        conf.Logger.Named("core"),
@@ -161,6 +165,7 @@ func (c *Core) addAPIServerRoutes() {
 	c.authhandle("/pool/{pool}/branch/{branch}", handleBranchGet).Methods("GET")
 	c.authhandle("/pool/{pool}/branch/{branch}", handleBranchDelete).Methods("DELETE")
 	c.authhandle("/pool/{pool}/branch/{branch}", handleBranchLoad).Methods("POST")
+	c.authhandle("/pool/{pool}/branch/{branch}/compact", handleCompact).Methods("POST")
 	c.authhandle("/pool/{pool}/branch/{branch}/delete", handleDelete).Methods("POST")
 	c.authhandle("/pool/{pool}/branch/{branch}/index", branchHandle(handleIndexApply)).Methods("POST")
 	c.authhandle("/pool/{pool}/branch/{branch}/index/update", branchHandle(handleIndexUpdate)).Methods("POST")
