@@ -8,13 +8,13 @@ import (
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/api"
 	"github.com/brimdata/zed/api/queryio"
-	"github.com/brimdata/zed/compiler"
 	"github.com/brimdata/zed/lake"
 	"github.com/brimdata/zed/lake/commits"
 	"github.com/brimdata/zed/lake/index"
 	"github.com/brimdata/zed/lake/journal"
 	"github.com/brimdata/zed/lakeparse"
 	"github.com/brimdata/zed/runtime"
+	"github.com/brimdata/zed/runtime/exec"
 	"github.com/brimdata/zed/runtime/op"
 	"github.com/brimdata/zed/service/auth"
 	"github.com/brimdata/zed/service/srverr"
@@ -38,12 +38,12 @@ func handleQuery(c *Core, w *ResponseWriter, r *Request) {
 	// The client must look at the return code and interpret the result
 	// accordingly and when it sees a ZNG error after underway,
 	// the error should be relay that to the caller/user.
-	query, err := compiler.ParseOp(req.Query)
+	query, err := c.compiler.Parse(req.Query)
 	if err != nil {
 		w.Error(srverr.ErrInvalid(err))
 		return
 	}
-	flowgraph, err := runtime.NewQueryOnLake(r.Context(), zed.NewContext(), query, c.root, &req.Head, r.Logger)
+	flowgraph, err := runtime.CompileLakeQuery(r.Context(), zed.NewContext(), c.compiler, query, &req.Head, r.Logger)
 	if err != nil {
 		w.Error(err)
 		return
@@ -58,46 +58,58 @@ func handleQuery(c *Core, w *ResponseWriter, r *Request) {
 	// response body and for errors after this point, we must call
 	// writer.WriterError() instead of w.Error().
 	defer writer.Close()
+	results := make(chan op.Result)
+	go func() {
+		for {
+			batch, err := flowgraph.Pull(false)
+			results <- op.Result{batch, err}
+			if batch == nil || err != nil {
+				return
+			}
+		}
+	}()
 	timer := time.NewTicker(queryStatsInterval)
 	defer timer.Stop()
 	meter := flowgraph.Meter()
 	for {
-		var tick bool
 		select {
 		case <-timer.C:
-			tick = true
-		default:
-		}
-		batch, err := flowgraph.Pull(false)
-		if err != nil {
-			if !errors.Is(err, journal.ErrEmpty) {
-				writer.WriteError(err)
-			}
-			return
-		}
-		if batch == nil || tick {
 			if err := writer.WriteProgress(meter.Progress()); err != nil {
 				writer.WriteError(err)
 				return
 			}
-			if batch == nil {
+		case r := <-results:
+			batch, err := r.Batch, r.Err
+			if err != nil {
+				if !errors.Is(err, journal.ErrEmpty) {
+					writer.WriteError(err)
+				}
 				return
 			}
-		}
-		if len(batch.Values()) == 0 {
-			if eoc, ok := batch.(*op.EndOfChannel); ok {
-				if err := writer.WhiteChannelEnd(int(*eoc)); err != nil {
+			if batch == nil {
+				if err := writer.WriteProgress(meter.Progress()); err != nil {
 					writer.WriteError(err)
 					return
 				}
+				if batch == nil {
+					return
+				}
+			}
+			if len(batch.Values()) == 0 {
+				if eoc, ok := batch.(*op.EndOfChannel); ok {
+					if err := writer.WhiteChannelEnd(int(*eoc)); err != nil {
+						writer.WriteError(err)
+						return
+					}
+				}
+				continue
+			}
+			var cid int
+			batch, cid = op.Unwrap(batch)
+			if err := writer.WriteBatch(cid, batch); err != nil {
+				writer.WriteError(err)
+				return
 			}
-			continue
-		}
-		var cid int
-		batch, cid = op.Unwrap(batch)
-		if err := writer.WriteBatch(cid, batch); err != nil {
-			writer.WriteError(err)
-			return
 		}
 	}
 }
@@ -155,7 +167,7 @@ func handlePoolStats(c *Core, w *ResponseWriter, r *Request) {
 		w.Error(err)
 		return
 	}
-	info, err := pool.Stats(r.Context(), snap)
+	info, err := exec.GetPoolStats(r.Context(), pool, snap)
 	if err != nil {
 		w.Error(err)
 		return
@@ -347,7 +359,7 @@ func handleBranchLoad(c *Core, w *ResponseWriter, r *Request) {
 	var opts anyio.ReaderOpts
 	opts.ZNG.Validate = true
 	zctx := zed.NewContext()
-	zrc, err := anyio.NewReaderWithOpts(anyio.GzipReader(r.Body), zctx, opts)
+	zrc, err := anyio.NewReaderWithOpts(zctx, anyio.GzipReader(r.Body), opts)
 	if err != nil {
 		w.Error(srverr.ErrInvalid(err))
 		return
@@ -377,6 +389,41 @@ func handleBranchLoad(c *Core, w *ResponseWriter, r *Request) {
 	})
 }
 
+func handleCompact(c *Core, w *ResponseWriter, r *Request) {
+	var req api.CompactRequest
+	if !r.Unmarshal(w, &req) {
+		return
+	}
+	poolID, ok := r.PoolID(w, c.root)
+	if !ok {
+		return
+	}
+	branch, ok := r.StringFromPath(w, "branch")
+	if !ok {
+		return
+	}
+	message, ok := r.decodeCommitMessage(w)
+	if !ok {
+		return
+	}
+	pool, err := c.root.OpenPool(r.Context(), poolID)
+	if err != nil {
+		w.Error(err)
+		return
+	}
+	commit, err := exec.Compact(r.Context(), pool, branch, req.ObjectIDs, message.Author, message.Body, message.Meta)
+	if err != nil {
+		w.Error(err)
+		return
+	}
+	w.Respond(http.StatusOK, api.CommitResponse{Commit: commit})
+	c.publishEvent(w, "branch-compact", api.EventBranchCommit{
+		CommitID: commit,
+		PoolID:   poolID,
+		Branch:   branch,
+	})
+}
+
 func handleDelete(c *Core, w *ResponseWriter, r *Request) {
 	poolID, ok := r.PoolID(w, c.root)
 	if !ok {
@@ -426,7 +473,7 @@ func handleDelete(c *Core, w *ResponseWriter, r *Request) {
 			w.Error(srverr.ErrInvalid("either object_ids or where must be set"))
 			return
 		}
-		commit, err = branch.DeleteByPredicate(r.Context(), c.root, payload.Where, message.Author, message.Body, message.Meta)
+		commit, err = branch.DeleteByPredicate(r.Context(), c.compiler, payload.Where, message.Author, message.Body, message.Meta)
 	}
 	if err != nil {
 		w.Error(err)
@@ -484,7 +531,7 @@ func handleIndexApply(c *Core, w *ResponseWriter, r *Request, branch *lake.Branc
 		w.Error(err)
 		return
 	}
-	commit, err := branch.ApplyIndexRules(r.Context(), rules, tags)
+	commit, err := branch.ApplyIndexRules(r.Context(), c.compiler, rules, tags)
 	if err != nil {
 		w.Error(err)
 		return
@@ -509,7 +556,7 @@ func handleIndexUpdate(c *Core, w *ResponseWriter, r *Request, branch *lake.Bran
 		w.Error(err)
 		return
 	}
-	commit, err := branch.UpdateIndex(r.Context(), rules)
+	commit, err := branch.UpdateIndex(r.Context(), c.compiler, rules)
 	if err != nil {
 		if errors.Is(err, commits.ErrEmptyTransaction) {
 			err = srverr.ErrInvalid(err)
@@ -542,7 +589,7 @@ func handleEvents(c *Core, w *ResponseWriter, r *Request) {
 		w.Error(srverr.ErrInvalid(err))
 	}
 	w.Header().Set("Content-Type", "text/event-stream")
-	writer := &eventStreamWriter{body: w, format: format}
+	writer := &eventStreamWriter{body: w.ResponseWriter, format: format}
 	subscription := make(chan event)
 	c.subscriptionsMu.Lock()
 	c.subscriptions[subscription] = struct{}{}
