@@ -17,30 +17,30 @@ import (
 	"github.com/brimdata/zed/zio/zstio"
 )
 
-func lookupReader(r io.Reader, zctx *zed.Context, opts ReaderOpts) (zio.ReadCloser, error) {
+func lookupReader(zctx *zed.Context, r io.Reader, opts ReaderOpts) (zio.ReadCloser, error) {
 	switch opts.Format {
 	case "csv":
-		return zio.NopReadCloser(csvio.NewReader(r, zctx)), nil
+		return zio.NopReadCloser(csvio.NewReader(zctx, r)), nil
 	case "zeek":
-		return zio.NopReadCloser(zeekio.NewReader(r, zctx)), nil
+		return zio.NopReadCloser(zeekio.NewReader(zctx, r)), nil
 	case "json":
-		return zio.NopReadCloser(jsonio.NewReader(r, zctx)), nil
+		return zio.NopReadCloser(jsonio.NewReader(zctx, r)), nil
 	case "zjson":
-		return zio.NopReadCloser(zjsonio.NewReader(r, zctx)), nil
+		return zio.NopReadCloser(zjsonio.NewReader(zctx, r)), nil
 	case "zng":
-		return zngio.NewReaderWithOpts(r, zctx, opts.ZNG), nil
+		return zngio.NewReaderWithOpts(zctx, r, opts.ZNG), nil
 	case "zng21":
-		return zio.NopReadCloser(zng21io.NewReaderWithOpts(r, zctx, opts.ZNG)), nil
+		return zio.NopReadCloser(zng21io.NewReaderWithOpts(zctx, r, opts.ZNG)), nil
 	case "zson":
-		return zio.NopReadCloser(zsonio.NewReader(r, zctx)), nil
+		return zio.NopReadCloser(zsonio.NewReader(zctx, r)), nil
 	case "zst":
-		zr, err := zstio.NewReader(r, zctx)
+		zr, err := zstio.NewReader(zctx, r)
 		if err != nil {
 			return nil, err
 		}
 		return zio.NopReadCloser(zr), nil
 	case "parquet":
-		zr, err := parquetio.NewReader(r, zctx)
+		zr, err := parquetio.NewReader(zctx, r)
 		if err != nil {
 			return nil, err
 		}
