@@ -47,7 +47,7 @@ func (w *Writer) Flush() error {
 
 func (w *Writer) Write(rec *zed.Value) error {
 	if rec.Type.Kind() != zed.RecordKind {
-		return fmt.Errorf("CSV output encountered non-record value: %s", zson.MustFormatValue(*rec))
+		return fmt.Errorf("CSV output encountered non-record value: %s", zson.MustFormatValue(rec))
 	}
 	rec, err := w.flattener.Flatten(rec)
 	if err != nil {
@@ -92,7 +92,7 @@ func (w *Writer) Write(rec *zed.Value) error {
 func formatValue(typ zed.Type, bytes zcode.Bytes) string {
 	// Avoid ZSON decoration.
 	if typ.ID() < zed.IDTypeComplex {
-		return zson.FormatPrimitive(typ, bytes)
+		return zson.FormatPrimitive(zed.TypeUnder(typ), bytes)
 	}
 	return zson.String(zed.Value{typ, bytes})
 }
