@@ -81,15 +81,15 @@ func (f *Formatter) FormatRecord(rec *zed.Value) (string, error) {
 	return f.builder.String(), nil
 }
 
-func FormatValue(zv zed.Value) (string, error) {
+func FormatValue(zv *zed.Value) (string, error) {
 	f := NewFormatter(0, nil)
 	return f.Format(zv)
 }
 
-func MustFormatValue(zv zed.Value) string {
+func MustFormatValue(zv *zed.Value) string {
 	s, err := FormatValue(zv)
 	if err != nil {
-		panic(fmt.Errorf("zson format value failed: type %s, bytes %s", zv.Type, hex.EncodeToString(zv.Bytes)))
+		panic(fmt.Errorf("ZSON format value failed: type %s, bytes %s", zv.Type, hex.EncodeToString(zv.Bytes)))
 	}
 	return s
 }
@@ -100,15 +100,15 @@ func String(p interface{}) string {
 	}
 	switch val := p.(type) {
 	case *zed.Value:
-		return MustFormatValue(*val)
-	case zed.Value:
 		return MustFormatValue(val)
+	case zed.Value:
+		return MustFormatValue(&val)
 	default:
 		panic("zson.String takes a zed.Type or *zed.Value")
 	}
 }
 
-func (f *Formatter) Format(zv zed.Value) (string, error) {
+func (f *Formatter) Format(zv *zed.Value) (string, error) {
 	f.builder.Reset()
 	if err := f.formatValueAndDecorate(zv.Type, zv.Bytes); err != nil {
 		return "", err
@@ -174,9 +174,9 @@ func (f *Formatter) formatValue(indent int, typ zed.Type, bytes zcode.Bytes, par
 	case *zed.TypeRecord:
 		err = f.formatRecord(indent, t, bytes, known, parentImplied)
 	case *zed.TypeArray:
-		null, err = f.formatVector(indent, "[", "]", t.Type, zed.Value{t, bytes}, known, parentImplied)
+		null, err = f.formatVector(indent, "[", "]", t.Type, zed.NewValue(t, bytes), known, parentImplied)
 	case *zed.TypeSet:
-		null, err = f.formatVector(indent, "|[", "]|", t.Type, zed.Value{t, bytes}, known, parentImplied)
+		null, err = f.formatVector(indent, "|[", "]|", t.Type, zed.NewValue(t, bytes), known, parentImplied)
 	case *zed.TypeUnion:
 		err = f.formatUnion(indent, t, bytes)
 	case *zed.TypeMap:
@@ -196,8 +196,10 @@ func (f *Formatter) formatValue(indent int, typ zed.Type, bytes zcode.Bytes, par
 		err = f.formatValue(indent, t.Type, bytes, known, parentImplied, false)
 		f.build(")")
 	case *zed.TypeOfType:
-		f.startColorPrimitive(zed.TypeType)
-		f.buildf("<%s>", FormatTypeValue(bytes))
+		f.startColor(color.Gray(200))
+		f.build("<")
+		f.formatTypeValue(indent, bytes)
+		f.build(">")
 		f.endColor()
 	}
 	if err == nil && decorate {
@@ -206,6 +208,172 @@ func (f *Formatter) formatValue(indent int, typ zed.Type, bytes zcode.Bytes, par
 	return err
 }
 
+func (f *Formatter) formatTypeValue(indent int, tv zcode.Bytes) zcode.Bytes {
+	n, tv := zed.DecodeLength(tv)
+	if tv == nil {
+		f.truncTypeValueErr()
+		return nil
+	}
+	switch n {
+	default:
+		if n < 0 || n > zed.TypeValueMax {
+			f.buildf("<ERR bad type ID %d in type value>", n)
+			return nil
+		}
+		typ := zed.LookupPrimitiveByID(int(n))
+		f.startColor(color.Gray(160))
+		f.build(zed.PrimitiveName(typ))
+		f.endColor()
+	case zed.TypeValueNameDef:
+		var name string
+		name, tv = zed.DecodeName(tv)
+		if tv == nil {
+			f.truncTypeValueErr()
+			return nil
+		}
+		f.build(name)
+		f.build("=")
+		tv = f.formatTypeValue(indent, tv)
+	case zed.TypeValueNameRef:
+		var name string
+		name, tv = zed.DecodeName(tv)
+		if tv == nil {
+			f.truncTypeValueErr()
+			return nil
+		}
+		f.build(name)
+	case zed.TypeValueRecord:
+		f.build("{")
+		var n int
+		n, tv = zed.DecodeLength(tv)
+		if tv == nil {
+			f.truncTypeValueErr()
+			return nil
+		}
+		if n == 0 {
+			f.build("}")
+			return tv
+		}
+		sep := f.newline
+		indent += f.tab
+		for k := 0; k < n; k++ {
+			f.build(sep)
+			var name string
+			name, tv = zed.DecodeName(tv)
+			if tv == nil {
+				f.truncTypeValueErr()
+				return nil
+			}
+			f.indent(indent, QuotedName(name))
+			f.build(":")
+			if f.tab > 0 {
+				f.build(" ")
+			}
+			tv = f.formatTypeValue(indent, tv)
+			sep = "," + f.newline
+		}
+		f.build(f.newline)
+		f.indent(indent-f.tab, "}")
+	case zed.TypeValueArray:
+		tv = f.formatVectorTypeValue(indent, "[", "]", tv)
+	case zed.TypeValueSet:
+		tv = f.formatVectorTypeValue(indent, "|[", "]|", tv)
+	case zed.TypeValueMap:
+		f.build("|{")
+		newline := f.newline
+		indent += f.tab
+		if n, itv := zed.DecodeLength(tv); n < zed.IDTypeComplex {
+			n, _ = zed.DecodeLength(itv)
+			if n < zed.IDTypeComplex {
+				// If key and value are both primitives don't indent.
+				indent -= f.tab
+				newline = ""
+			}
+		}
+		f.build(newline)
+		f.indent(indent, "")
+		tv = f.formatTypeValue(indent, tv)
+		f.build(":")
+		if f.tab > 0 {
+			f.build(" ")
+		}
+		tv = f.formatTypeValue(indent, tv)
+		f.build(newline)
+		if newline != "" {
+			f.indent(indent-f.tab, "}|")
+		} else {
+			f.build("}|")
+		}
+	case zed.TypeValueUnion:
+		f.build("(")
+		var n int
+		n, tv = zed.DecodeLength(tv)
+		if tv == nil {
+			f.truncTypeValueErr()
+			return nil
+		}
+		sep := f.newline
+		indent += f.tab
+		for k := 0; k < n; k++ {
+			f.build(sep)
+			f.indent(indent, "")
+			tv = f.formatTypeValue(indent, tv)
+			sep = "," + f.newline
+		}
+		f.build(f.newline)
+		f.indent(indent-f.tab, ")")
+	case zed.TypeValueEnum:
+		f.build("enum(")
+		var n int
+		n, tv = zed.DecodeLength(tv)
+		if tv == nil {
+			f.truncTypeValueErr()
+			return nil
+		}
+		for k := 0; k < n; k++ {
+			if k > 0 {
+				f.build(",")
+			}
+			var symbol string
+			symbol, tv = zed.DecodeName(tv)
+			if tv == nil {
+				f.truncTypeValueErr()
+				return nil
+			}
+			f.build(QuotedName(symbol))
+		}
+		f.build(")")
+	case zed.TypeValueError:
+		f.startColor(color.Red)
+		f.build("error")
+		f.endColor()
+		f.build("(")
+		tv = f.formatTypeValue(indent, tv)
+		f.build(")")
+	}
+	return tv
+}
+
+func (f *Formatter) formatVectorTypeValue(indent int, open, close string, tv zcode.Bytes) zcode.Bytes {
+	f.build(open)
+	if n, _ := zed.DecodeLength(tv); n < zed.IDTypeComplex {
+		tv = f.formatTypeValue(indent, tv)
+		f.build(close)
+		return tv
+	}
+	indent += f.tab
+	f.build(f.newline)
+	f.indent(indent, "")
+	tv = f.formatTypeValue(indent, tv)
+	f.build(f.newline)
+	f.indent(indent-f.tab, close)
+	return tv
+}
+
+func (f *Formatter) truncTypeValueErr() {
+	f.build("<ERR truncated type value>")
+}
+
 func (f *Formatter) nextInternalType() string {
 	name := strconv.Itoa(f.nid)
 	f.nid++
@@ -272,7 +440,7 @@ func (f *Formatter) formatRecord(indent int, typ *zed.TypeRecord, bytes zcode.By
 	return nil
 }
 
-func (f *Formatter) formatVector(indent int, open, close string, inner zed.Type, zv zed.Value, known, parentImplied bool) (bool, error) {
+func (f *Formatter) formatVector(indent int, open, close string, inner zed.Type, zv *zed.Value, known, parentImplied bool) (bool, error) {
 	f.build(open)
 	n, err := zv.ContainerLength()
 	if err != nil {
@@ -658,6 +826,7 @@ func FormatPrimitive(typ zed.Type, bytes zcode.Bytes) string {
 func formatPrimitive(b *strings.Builder, typ zed.Type, bytes zcode.Bytes) {
 	if bytes == nil {
 		b.WriteString("null")
+		return
 	}
 	switch typ := typ.(type) {
 	case *zed.TypeOfUint8, *zed.TypeOfUint16, *zed.TypeOfUint32, *zed.TypeOfUint64:
@@ -699,138 +868,15 @@ func formatPrimitive(b *strings.Builder, typ zed.Type, bytes zcode.Bytes) {
 		b.WriteString(zed.DecodeNet(bytes).String())
 	case *zed.TypeOfType:
 		b.WriteByte('<')
-		formatTypeValue(bytes, b)
+		b.WriteString(FormatTypeValue(bytes))
 		b.WriteByte('>')
 	default:
-		b.WriteString(fmt.Sprintf("<zson unknown primitive: %T", typ))
+		b.WriteString(fmt.Sprintf("<ZSON unknown primitive: %T>", typ))
 	}
 }
 
 func FormatTypeValue(tv zcode.Bytes) string {
-	var b strings.Builder
-	formatTypeValue(tv, &b)
-	return b.String()
-}
-
-func formatTypeValue(tv zcode.Bytes, b *strings.Builder) zcode.Bytes {
-	if len(tv) == 0 {
-		truncErr(b)
-		return nil
-	}
-	id := tv[0]
-	tv = tv[1:]
-	switch id {
-	case zed.TypeValueNameDef:
-		name, tv := decodeNameAndCheck(tv, b)
-		if tv == nil {
-			return nil
-		}
-		b.WriteString(name)
-		b.WriteString("=")
-		tv = formatTypeValue(tv, b)
-		return tv
-	case zed.TypeValueNameRef:
-		name, tv := decodeNameAndCheck(tv, b)
-		if tv == nil {
-			return nil
-		}
-		b.WriteString(name)
-		return tv
-	case zed.TypeValueRecord:
-		b.WriteByte('{')
-		var n int
-		n, tv = zed.DecodeLength(tv)
-		if tv == nil {
-			truncErr(b)
-			return nil
-		}
-		for k := 0; k < n; k++ {
-			if k > 0 {
-				b.WriteByte(',')
-			}
-			var name string
-			name, tv = decodeNameAndCheck(tv, b)
-			b.WriteString(QuotedName(name))
-			b.WriteString(":")
-			tv = formatTypeValue(tv, b)
-			if tv == nil {
-				return nil
-			}
-		}
-		b.WriteByte('}')
-	case zed.TypeValueArray:
-		b.WriteByte('[')
-		tv = formatTypeValue(tv, b)
-		b.WriteByte(']')
-	case zed.TypeValueSet:
-		b.WriteString("|[")
-		tv = formatTypeValue(tv, b)
-		b.WriteString("]|")
-	case zed.TypeValueMap:
-		b.WriteString("|{")
-		tv = formatTypeValue(tv, b)
-		b.WriteByte(':')
-		tv = formatTypeValue(tv, b)
-		b.WriteString("}|")
-	case zed.TypeValueUnion:
-		b.WriteByte('(')
-		var n int
-		n, tv = zed.DecodeLength(tv)
-		if tv == nil {
-			truncErr(b)
-			return nil
-		}
-		for k := 0; k < n; k++ {
-			if k > 0 {
-				b.WriteByte(',')
-			}
-			tv = formatTypeValue(tv, b)
-		}
-		b.WriteByte(')')
-	case zed.TypeValueEnum:
-		b.WriteString("enum(")
-		var n int
-		n, tv = zed.DecodeLength(tv)
-		if tv == nil {
-			truncErr(b)
-			return nil
-		}
-		for k := 0; k < n; k++ {
-			if k > 0 {
-				b.WriteByte(',')
-			}
-			var symbol string
-			symbol, tv = decodeNameAndCheck(tv, b)
-			if tv == nil {
-				return nil
-			}
-			b.WriteString(QuotedName(symbol))
-		}
-		b.WriteByte(')')
-	case zed.TypeValueError:
-		b.WriteString("error(")
-		tv = formatTypeValue(tv, b)
-		b.WriteByte(')')
-	default:
-		if id < 0 || id > zed.TypeValueMax {
-			b.WriteString(fmt.Sprintf("<ERR bad type ID %d in type value>", id))
-			return nil
-		}
-		typ := zed.LookupPrimitiveByID(int(id))
-		b.WriteString(zed.PrimitiveName(typ))
-	}
-	return tv
-}
-
-func decodeNameAndCheck(tv zcode.Bytes, b *strings.Builder) (string, zcode.Bytes) {
-	var name string
-	name, tv = zed.DecodeName(tv)
-	if tv == nil {
-		truncErr(b)
-	}
-	return name, tv
-}
-
-func truncErr(b *strings.Builder) {
-	b.WriteString("<ERR truncated type value>")
+	f := NewFormatter(0, nil)
+	f.formatTypeValue(0, tv)
+	return f.builder.String()
 }
