@@ -4,6 +4,7 @@ import (
 	"errors"
 	"fmt"
 	"net"
+	"net/netip"
 	"reflect"
 	"strings"
 	"time"
@@ -11,7 +12,6 @@ import (
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/pkg/nano"
 	"github.com/brimdata/zed/zcode"
-	"inet.af/netaddr"
 )
 
 //XXX handle new TypeError => marshal as a ZSON string?
@@ -290,7 +290,7 @@ func (m *MarshalZNGContext) encodeValue(v reflect.Value) (zed.Type, error) {
 			// it's already been converted to a Zed time;
 			// likewise for zed.Value, which gets encoded as
 			// itself and its own named type if it has one.
-			if t := v.Type(); t == nanoTsType || t == zngValueType {
+			if t := v.Type(); t == nanoTsType || t == zngValueType || t == netipAddrType || t == netIPType {
 				return typ, nil
 			}
 			path := v.Type().PkgPath()
@@ -329,6 +329,16 @@ func (m *MarshalZNGContext) encodeAny(v reflect.Value) (zed.Type, error) {
 		m.Builder.Append(zv.Bytes)
 		return typ, nil
 	}
+	if ip, ok := v.Interface().(net.IP); ok {
+		if a, err := netip.ParseAddr(ip.String()); err == nil {
+			m.Builder.Append(zed.EncodeIP(a))
+			return zed.TypeIP, nil
+		}
+	}
+	if t, ok := v.Interface().(time.Time); ok {
+		m.Builder.Append(zed.EncodeTime(nano.TimeToTs(t)))
+		return zed.TypeTime, nil
+	}
 	switch v.Kind() {
 	case reflect.Array:
 		if v.Type().Elem().Kind() == reflect.Uint8 {
@@ -349,9 +359,8 @@ func (m *MarshalZNGContext) encodeAny(v reflect.Value) (zed.Type, error) {
 		}
 		return m.encodeArray(v)
 	case reflect.Struct:
-		if isIP(v.Type()) {
-			ip := v.Interface().(netaddr.IP)
-			m.Builder.Append(zed.EncodeIP(ip))
+		if a, ok := v.Interface().(netip.Addr); ok {
+			m.Builder.Append(zed.EncodeIP(a))
 			return zed.TypeIP, nil
 		}
 		return m.encodeRecord(v)
@@ -474,6 +483,10 @@ func (m *MarshalZNGContext) encodeRecord(sval reflect.Value) (zed.Type, error) {
 		}
 		field := stype.Field(i)
 		name := fieldName(field)
+		if name == "-" {
+			// Ignore fields named "-".
+			continue
+		}
 		typ, err := m.encodeValue(sval.Field(i))
 		if err != nil {
 			return nil, err
@@ -647,6 +660,9 @@ func (u *UnmarshalZNGContext) NamedBindings(bindings []Binding) error {
 	return nil
 }
 
+var netipAddrType = reflect.TypeOf(netip.Addr{})
+var netIPType = reflect.TypeOf(net.IP{})
+
 func (u *UnmarshalZNGContext) decodeAny(zv *zed.Value, v reflect.Value) error {
 	if !v.IsValid() {
 		return errors.New("cannot unmarshal into value provided")
@@ -693,10 +709,13 @@ func (u *UnmarshalZNGContext) decodeAny(zv *zed.Value, v reflect.Value) error {
 	case reflect.Map:
 		return u.decodeMap(zv, v)
 	case reflect.Slice:
+		if v.Type() == netIPType {
+			return u.decodeNetIP(zv, v)
+		}
 		return u.decodeArray(zv, v)
 	case reflect.Struct:
-		if isIP(v.Type()) {
-			return u.decodeIP(zv, v)
+		if v.Type() == netipAddrType {
+			return u.decodeNetipAddr(zv, v)
 		}
 		return u.decodeRecord(zv, v)
 	case reflect.Interface:
@@ -833,11 +852,7 @@ func (u *UnmarshalZNGContext) decodeNull(zv *zed.Value, v reflect.Value) error {
 	return nil
 }
 
-func isIP(typ reflect.Type) bool {
-	return typ.Name() == "IP" && typ.PkgPath() == "inet.af/netaddr"
-}
-
-func (u *UnmarshalZNGContext) decodeIP(zv *zed.Value, v reflect.Value) error {
+func (u *UnmarshalZNGContext) decodeNetipAddr(zv *zed.Value, v reflect.Value) error {
 	if zed.TypeUnder(zv.Type) != zed.TypeIP {
 		return incompatTypeError(zv.Type, v)
 	}
@@ -849,6 +864,18 @@ func (u *UnmarshalZNGContext) decodeIP(zv *zed.Value, v reflect.Value) error {
 	return nil
 }
 
+func (u *UnmarshalZNGContext) decodeNetIP(zv *zed.Value, v reflect.Value) error {
+	if zed.TypeUnder(zv.Type) != zed.TypeIP {
+		return incompatTypeError(zv.Type, v)
+	}
+	if zv.Bytes == nil {
+		v.Set(reflect.Zero(v.Type()))
+		return nil
+	}
+	v.Set(reflect.ValueOf(net.ParseIP(zed.DecodeIP(zv.Bytes).String())))
+	return nil
+}
+
 func (u *UnmarshalZNGContext) decodeMap(zv *zed.Value, mapVal reflect.Value) error {
 	typ, ok := zed.TypeUnder(zv.Type).(*zed.TypeMap)
 	if !ok {
@@ -1139,7 +1166,7 @@ func (u *UnmarshalZNGContext) lookupPrimitiveType(typ zed.Type) (reflect.Type, e
 	case *zed.TypeOfFloat64:
 		v = float64(0)
 	case *zed.TypeOfIP:
-		v = netaddr.IP{}
+		v = netip.Addr{}
 	case *zed.TypeOfNet:
 		v = net.IPNet{}
 	case *zed.TypeOfTime:
