@@ -2,8 +2,11 @@ package zson_test
 
 import (
 	"bytes"
+	"net"
+	"net/netip"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/zio"
@@ -208,13 +211,12 @@ func TestBug2575(t *testing.T) {
 	require.NoError(t, err)
 
 	var buffer bytes.Buffer
-	writer := zngio.NewWriter(zio.NopCloser(&buffer), zngio.WriterOpts{})
+	writer := zngio.NewWriter(zio.NopCloser(&buffer))
 	recExpected := zed.NewValue(zv.Type, zv.Bytes)
 	writer.Write(recExpected)
 	writer.Close()
 
-	r := bytes.NewReader(buffer.Bytes())
-	reader := zngio.NewReader(r, zed.NewContext())
+	reader := zngio.NewReader(zed.NewContext(), &buffer)
 	defer reader.Close()
 	recActual, err := reader.Read()
 	exp, err := zson.FormatValue(recExpected)
@@ -295,3 +297,58 @@ func TestJSONFieldTag(t *testing.T) {
 	require.NoError(t, zson.Unmarshal(s, &j))
 	assert.Equal(t, jsonTag{Value: "test"}, j)
 }
+
+func TestIgnoreField(t *testing.T) {
+	type s struct {
+		Value  string       `zed:"value"`
+		Ignore func() error `zed:"-"`
+	}
+	b, err := zson.Marshal(s{Value: "test"})
+	require.NoError(t, err)
+	assert.Equal(t, `{value:"test"}`, b)
+	var v s
+	require.NoError(t, zson.Unmarshal(b, &v))
+	assert.Equal(t, s{Value: "test"}, v)
+}
+
+func TestMarshalNetIP(t *testing.T) {
+	before := net.ParseIP("10.0.0.1")
+	b, err := zson.Marshal(before)
+	require.NoError(t, err)
+	assert.Equal(t, `10.0.0.1`, b)
+	var after net.IP
+	err = zson.Unmarshal(string(b), &after)
+	require.NoError(t, err)
+	assert.Equal(t, before, after)
+}
+
+func TestMarshalNetipAddr(t *testing.T) {
+	before := netip.MustParseAddr("10.0.0.1")
+	b, err := zson.Marshal(before)
+	require.NoError(t, err)
+	assert.Equal(t, `10.0.0.1`, b)
+	var after netip.Addr
+	err = zson.Unmarshal(string(b), &after)
+	require.NoError(t, err)
+	assert.Equal(t, before, after)
+}
+
+func TestMarshalDecoratedIPs(t *testing.T) {
+	m := zson.NewMarshaler()
+	// Make sure IPs don't get decorated with Go type and just
+	// appear as native Zed IPs.
+	m.Decorate(zson.StyleSimple)
+	b, err := m.Marshal(net.ParseIP("142.250.72.142"))
+	require.NoError(t, err)
+	assert.Equal(t, `142.250.72.142`, b)
+	b, err = m.Marshal(netip.MustParseAddr("142.250.72.142"))
+	require.NoError(t, err)
+	assert.Equal(t, `142.250.72.142`, b)
+}
+
+func TestMarshalGoTime(t *testing.T) {
+	tm, _ := time.Parse(time.RFC3339, "2006-01-02T15:04:05.123Z")
+	b, err := zson.Marshal(tm)
+	require.NoError(t, err)
+	assert.Equal(t, `2006-01-02T15:04:05.123Z`, b)
+}
