@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"errors"
 	"math"
+	"net/netip"
 	"strings"
 	"testing"
 
@@ -15,7 +16,6 @@ import (
 	"github.com/brimdata/zed/zson"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"inet.af/netaddr"
 )
 
 func toZSON(t *testing.T, rec *zed.Value) string {
@@ -28,11 +28,12 @@ func boomerang(t *testing.T, in interface{}, out interface{}) {
 	rec, err := zson.NewZNGMarshaler().MarshalRecord(in)
 	require.NoError(t, err)
 	var buf bytes.Buffer
-	zw := zngio.NewWriter(zio.NopCloser(&buf), zngio.WriterOpts{})
+	zw := zngio.NewWriter(zio.NopCloser(&buf))
 	err = zw.Write(rec)
 	require.NoError(t, err)
+	require.NoError(t, zw.Close())
 	zctx := zed.NewContext()
-	zr := zngio.NewReader(&buf, zctx)
+	zr := zngio.NewReader(zctx, &buf)
 	defer zr.Close()
 	rec, err = zr.Read()
 	require.NoError(t, err)
@@ -141,11 +142,11 @@ func TestMarshalTime(t *testing.T) {
 }
 
 type TestIP struct {
-	Addr netaddr.IP
+	Addr netip.Addr
 }
 
 func TestIPType(t *testing.T) {
-	s := TestIP{Addr: netaddr.MustParseIP("192.168.1.1")}
+	s := TestIP{Addr: netip.MustParseAddr("192.168.1.1")}
 	zctx := zed.NewContext()
 	m := zson.NewZNGMarshalerWithContext(zctx)
 	rec, err := m.MarshalRecord(s)
@@ -182,8 +183,7 @@ func TestUnmarshalRecord(t *testing.T) {
 	const expected = `{top:{T2f1:{T3f1:1(int32),T3f2:1.(float32)},T2f2:"t2f2-string1"}}`
 	require.Equal(t, expected, toZSON(t, rec))
 
-	zctx := zed.NewContext()
-	rec, err = zsonio.NewReader(strings.NewReader(expected), zctx).Read()
+	rec, err = zsonio.NewReader(zed.NewContext(), strings.NewReader(expected)).Read()
 	require.NoError(t, err)
 
 	var v2 T1
