@@ -168,7 +168,7 @@ func (o *Object) newSectionReader(level int, sectionOff int64) *zngio.Reader {
 	off += sectionOff
 	len -= sectionOff
 	reader := io.NewSectionReader(o.seeker, off, len)
-	return zngio.NewReader(reader, o.zctx)
+	return zngio.NewReader(o.zctx, reader)
 }
 
 func (o *Object) NewReassemblyReader() *zngio.Reader {
